@@ -3,6 +3,7 @@ from io import StringIO
 from pathlib import Path
 
 import numpy as np
+import pandas as pd
 import pytest
 from Bio import Phylo
 
@@ -113,6 +114,13 @@ def test_circos_link_plot(fig_outfile: Path):
     assert fig_outfile.exists()
 
 
+def test_chord_diagram_plot(fig_outfile: Path, tsv_matrix_file: pd.DataFrame):
+    """Test chord diagram plot"""
+    circos = Circos.initialize_from_matrix(tsv_matrix_file)
+    circos.savefig(fig_outfile)
+    assert fig_outfile.exists()
+
+
 def test_cytoband_plot(fig_outfile: Path, hg38_testdata_dir: Path):
     """Test hg38 cytoband plot"""
     # Add tracks for cytoband plot
@@ -352,6 +360,7 @@ def test_track_yticks_plot(fig_outfile: Path):
             y_labels,
             vmin=10,
             vmax=25,
+            side="left",
             line_kws=dict(color="red", lw=1),
             text_kws=dict(color="blue"),
         )
